declare module '@hiiretail/react-foundation-ui/common/types/theme.types' {
  export type Color = 'primary' | 'secondary' | 'error';

}
declare module '@hiiretail/react-foundation-ui/common/types/utils' {
  export type ChangeFields<T, R> = Omit<T, keyof R> & R;

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/AlertNotification' {
  import React from 'react';
  import { AlertNotificationDetails } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';
  /**
   * React Functional Component for alerts if the Provider + Hook version could not be used for some reason.
   *
   * @see https://github.com/extenda/react-foundation-ui#4-components-reference
   */
  export const AlertNotification: React.FC<AlertNotificationDetails>;

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/AlertNotificationContent' {
  import React from 'react';
  import { AlertNotificationDetails } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';
  export const AlertNotificationContent: React.ForwardRefExoticComponent<AlertNotificationDetails & React.RefAttributes<HTMLDivElement>>;

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/AlertNotificationProvider' {
  import React, { ReactNode } from 'react';
  import type { AlertNotificationUtils } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';
  export const AlertNotificationContext: React.Context<AlertNotificationUtils>;
  type AlertNotificationSnackbarWrapperProps = {
      children: ReactNode;
  };
  export const AlertNotificationProvider: React.FC<AlertNotificationSnackbarWrapperProps>;
  export {};

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/configs' {
  import { AlertNotificationType } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';
  export const alertConfig: {
      [key in AlertNotificationType]: {
          borderColor: string;
      };
  };

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/hooks/useAlertNotifications' {
  import type { AlertNotificationUtils } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';
  type UseAlertNotifications = () => AlertNotificationUtils;
  /**
   * Returns methods to Show and Hide Notification alerts.
   *
   * @see https://github.com/extenda/react-foundation-ui#4-components-reference
   */
  export const useAlertNotifications: UseAlertNotifications;
  export {};

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/index' {
  export { AlertNotification } from '@hiiretail/react-foundation-ui/components/AlertNotifications/AlertNotification';
  export { AlertNotificationProvider } from '@hiiretail/react-foundation-ui/components/AlertNotifications/AlertNotificationProvider';
  export { useAlertNotifications } from '@hiiretail/react-foundation-ui/components/AlertNotifications/hooks/useAlertNotifications';
  export { AlertNotificationType, type AlertNotificationDetails } from '@hiiretail/react-foundation-ui/components/AlertNotifications/types';

}
declare module '@hiiretail/react-foundation-ui/components/AlertNotifications/types' {
  export type AlertNotificationDetails = {
      message: string;
      open?: boolean;
      title?: string;
      type?: AlertNotificationType;
      autoHideTime?: number;
      onClose?: () => void;
      id?: string;
  };
  export enum AlertNotificationType {
      ERROR = "error",
      WARNING = "warning",
      INFO = "info",
      SUCCESS = "success"
  }
  export type AlertNotificationUtils = {
      show: (alertDetails: AlertNotificationDetails) => string;
      hide: (alertKey?: string) => void;
  };

}
declare module '@hiiretail/react-foundation-ui/components/Avatar/Avatar' {
  import type { FC, PropsWithChildren } from 'react';
  import type { AvatarProps } from '@mui/material/Avatar';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationAvatarProps = ChangeFields<AvatarProps, {
      variant?: Exclude<AvatarProps['variant'], 'square'>;
  }>;
  export const Avatar: FC<PropsWithChildren<FoundationAvatarProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Avatar/index' {
  export { Avatar } from '@hiiretail/react-foundation-ui/components/Avatar/Avatar';

}
declare module '@hiiretail/react-foundation-ui/components/Badge/Badge' {
  import type { FC, PropsWithChildren } from 'react';
  import type { BadgeProps } from '@mui/material/Badge';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  import type { Color } from '@hiiretail/react-foundation-ui/common/types/theme.types';
  export type FoundationBadgeProps = ChangeFields<BadgeProps, {
      color?: Color;
  }>;
  export const Badge: FC<PropsWithChildren<FoundationBadgeProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Badge/index' {
  export { Badge } from '@hiiretail/react-foundation-ui/components/Badge/Badge';

}
declare module '@hiiretail/react-foundation-ui/components/Button/Button' {
  import type { FC, PropsWithChildren } from 'react';
  import type { ButtonProps } from '@mui/material/Button';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  import type { Color } from '@hiiretail/react-foundation-ui/common/types/theme.types';
  export type FoundationButtonProps = ChangeFields<ButtonProps, {
      color?: Color;
      variant?: Exclude<ButtonProps['variant'], 'outlined'>;
  }>;
  export const Button: FC<PropsWithChildren<FoundationButtonProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Button/index' {
  export { Button } from '@hiiretail/react-foundation-ui/components/Button/Button';

}
declare module '@hiiretail/react-foundation-ui/components/ButtonGroup/ButtonGroup' {
  import type { FC, PropsWithChildren } from 'react';
  import type { ButtonGroupProps } from '@mui/material/ButtonGroup';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationButtonGroupProps = ChangeFields<ButtonGroupProps, {
      color?: Exclude<ButtonGroupProps['color'], 'error' | 'info' | 'success' | 'warning'>;
  }>;
  export const ButtonGroup: FC<PropsWithChildren<FoundationButtonGroupProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/ButtonGroup/index' {
  export { ButtonGroup } from '@hiiretail/react-foundation-ui/components/ButtonGroup/ButtonGroup';

}
declare module '@hiiretail/react-foundation-ui/components/Checkbox/Checkbox' {
  import type { FC, PropsWithChildren } from 'react';
  import type { CheckboxProps } from "@mui/material";
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationCheckboxProps = ChangeFields<CheckboxProps, {
      color?: Exclude<CheckboxProps['color'], 'info' | 'success' | 'warning' | 'error'>;
  }>;
  export const Checkbox: FC<PropsWithChildren<FoundationCheckboxProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Checkbox/index' {
  export { Checkbox } from "@hiiretail/react-foundation-ui/components/Checkbox/Checkbox";

}
declare module '@hiiretail/react-foundation-ui/components/Chip/Chip' {
  import type { FC, PropsWithChildren } from 'react';
  import type { ChipProps } from '@mui/material';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationChipProps = ChangeFields<ChipProps, {
      color?: Exclude<ChipProps['color'], 'error' | 'info' | 'success' | 'warning'>;
      variant?: Exclude<ChipProps['variant'], 'outlined'>;
  }>;
  export const Chip: FC<PropsWithChildren<FoundationChipProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Chip/index' {
  export { Chip } from '@hiiretail/react-foundation-ui/components/Chip/Chip';

}
declare module '@hiiretail/react-foundation-ui/components/DataGrid/index' {
  export { DataGrid } from '@mui/x-data-grid';

}
declare module '@hiiretail/react-foundation-ui/components/DialogActions/DialogActions' {
  import type { DialogActionsProps } from "@mui/material/DialogActions";
  import type { FC, PropsWithChildren } from "react";
  import type { SxProps } from "@mui/material";
  import type { ChangeFields } from "@hiiretail/react-foundation-ui/common/types/utils";
  export type FoundationDialogActionsProps = ChangeFields<DialogActionsProps, {
      sx?: SxProps;
  }>;
  export const DialogActions: FC<PropsWithChildren<FoundationDialogActionsProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/DialogActions/index' {
  export { DialogActions } from '@hiiretail/react-foundation-ui/components/DialogActions/DialogActions';

}
declare module '@hiiretail/react-foundation-ui/components/FoundationProvider/FoundationProvider' {
  import React, { PropsWithChildren } from 'react';
  export const themeOptions: {
      palette: {
          type: string;
          primary: {
              main: string;
          };
          secondary: {
              main: string;
          };
          error: {
              main: string;
          };
      };
      shape: {
          borderRadius: number;
      };
      typography: {
          fontFamily: string;
      };
  };
  export const FoundationProvider: React.FC<PropsWithChildren<{}>>;

}
declare module '@hiiretail/react-foundation-ui/components/FoundationProvider/index' {
  export { FoundationProvider } from '@hiiretail/react-foundation-ui/components/FoundationProvider/FoundationProvider';

}
declare module '@hiiretail/react-foundation-ui/components/IconButton/IconButton' {
  import React from 'react';
  import type { IconButtonProps } from '@mui/material/IconButton';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationIconButtonProps = ChangeFields<IconButtonProps, {
      color?: Exclude<IconButtonProps['color'], 'info' | 'success' | 'warning'>;
  }>;
  export const IconButton: React.ForwardRefExoticComponent<Pick<React.PropsWithChildren<FoundationIconButtonProps>, "type" | "children" | "form" | "slot" | "title" | keyof import("@mui/material/OverridableComponent").CommonProps | "sx" | "key" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "color" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "name" | "autoFocus" | "disabled" | "formAction" | "formEncType" | "formMethod" | "formNoValidate" | "formTarget" | "value" | "action" | "size" | "centerRipple" | "disableRipple" | "disableTouchRipple" | "focusRipple" | "focusVisibleClassName" | "LinkComponent" | "onFocusVisible" | "TouchRippleProps" | "touchRippleRef" | "disableFocusRipple" | "edge"> & React.RefAttributes<React.FC<{}>>>;

}
declare module '@hiiretail/react-foundation-ui/components/IconButton/index' {
  export { IconButton } from '@hiiretail/react-foundation-ui/components/IconButton/IconButton';

}
declare module '@hiiretail/react-foundation-ui/components/Radio/Radio' {
  import type { FC, PropsWithChildren } from 'react';
  import type { RadioProps } from '@mui/material/Radio';
  import type { ChangeFields } from '@hiiretail/react-foundation-ui/common/types/utils';
  export type FoundationRadioProps = ChangeFields<RadioProps, {
      color?: Exclude<RadioProps['color'], 'info' | 'success' | 'warning' | 'error'>;
  }>;
  export const Radio: FC<PropsWithChildren<FoundationRadioProps>>;

}
declare module '@hiiretail/react-foundation-ui/components/Radio/index' {
  export { Radio } from '@hiiretail/react-foundation-ui/components/Radio/Radio';

}
declare module '@hiiretail/react-foundation-ui/components/index' {
  export { FoundationProvider } from '@hiiretail/react-foundation-ui/components/FoundationProvider/index';
  export { Avatar } from '@hiiretail/react-foundation-ui/components/Avatar/index';
  export { Badge } from '@hiiretail/react-foundation-ui/components/Badge/index';
  export { Button } from '@hiiretail/react-foundation-ui/components/Button/index';
  export { ButtonGroup } from '@hiiretail/react-foundation-ui/components/ButtonGroup/index';
  export { IconButton } from '@hiiretail/react-foundation-ui/components/IconButton/index';
  export { Radio } from '@hiiretail/react-foundation-ui/components/Radio/index';
  export { DialogActions } from '@hiiretail/react-foundation-ui/components/DialogActions/index';
  export { Checkbox } from '@hiiretail/react-foundation-ui/components/Checkbox/index';
  export { Chip } from '@hiiretail/react-foundation-ui/components/Chip/index';
  export { DataGrid } from '@hiiretail/react-foundation-ui/components/DataGrid/index';

}
declare module '@hiiretail/react-foundation-ui/index' {
  import { Accordion, AccordionActions, AccordionDetails, AccordionSummary, Alert, AlertTitle, AppBar, Autocomplete, AvatarGroup, Backdrop, BottomNavigation, BottomNavigationAction, Box, Breadcrumbs, Card, CardActionArea, CardActions, CardContent, CardHeader, CardMedia, Checkbox, Chip, CircularProgress, ClickAwayListener, Collapse, Container, CssBaseline, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Divider, Drawer, Fab, Fade, FilledInput, FormControl, FormControlLabel, FormGroup, FormHelperText, FormLabel, Grid, Grow, Hidden, Icon, ImageList, ImageListItem, ImageListItemBar, Input, InputAdornment, InputBase, InputLabel, LinearProgress, Link, List, ListItem, ListItemAvatar, ListItemButton, ListItemIcon, ListItemSecondaryAction, ListItemText, ListSubheader, Menu, MenuItem, MenuList, MobileStepper, Modal, NativeSelect, NoSsr, OutlinedInput, Pagination, PaginationItem, Paper, Popover, Popper, Portal, RadioGroup, Rating, ScopedCssBaseline, Select, Skeleton, Slide, Slider, Snackbar, SnackbarContent, SpeedDial, SpeedDialAction, SpeedDialIcon, Stack, Step, StepButton, StepConnector, StepContent, StepIcon, StepLabel, Stepper, SvgIcon, SwipeableDrawer, Switch, Tab, Table, TableBody, TableCell, TableContainer, TableFooter, TableHead, TablePagination, TableRow, TableSortLabel, Tabs, TabScrollButton, TextField, TextareaAutosize, ToggleButton, ToggleButtonGroup, Toolbar, Tooltip, Typography, useMediaQuery, useScrollTrigger, Zoom, useAutocomplete, GlobalStyles } from '@mui/material';
  import * as emotionReact from '@emotion/react';
  import * as emotionStyled from '@emotion/styled';
  import { FoundationProvider } from '@hiiretail/react-foundation-ui/components/index';
  import { Avatar, Badge, Button, ButtonGroup, DataGrid, IconButton, Radio } from '@hiiretail/react-foundation-ui/components/index';
  import { AlertNotification, AlertNotificationProvider, useAlertNotifications } from '@hiiretail/react-foundation-ui/components/AlertNotifications/index';
  import { AlertNotificationType, type AlertNotificationDetails } from '@hiiretail/react-foundation-ui/components/AlertNotifications/index';
  export { Avatar, Badge, Button, ButtonGroup, DataGrid, IconButton, FoundationProvider, Radio, AlertNotification, AlertNotificationProvider, useAlertNotifications, AlertNotificationType, AlertNotificationDetails, Accordion, AccordionActions, AccordionDetails, AccordionSummary, Alert, AlertTitle, AppBar, Autocomplete, AvatarGroup, Backdrop, BottomNavigation, BottomNavigationAction, Box, Breadcrumbs, Card, CardActionArea, CardActions, CardContent, CardHeader, CardMedia, Checkbox, Chip, CircularProgress, ClickAwayListener, Collapse, Container, CssBaseline, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Divider, Drawer, Fab, Fade, FilledInput, FormControl, FormControlLabel, FormGroup, FormHelperText, FormLabel, Grid, Grow, Hidden, Icon, ImageList, ImageListItem, ImageListItemBar, Input, InputAdornment, InputBase, InputLabel, LinearProgress, Link, List, ListItem, ListItemAvatar, ListItemButton, ListItemIcon, ListItemSecondaryAction, ListItemText, ListSubheader, Menu, MenuItem, MenuList, MobileStepper, Modal, NativeSelect, NoSsr, OutlinedInput, Pagination, PaginationItem, Paper, Popover, Popper, Portal, RadioGroup, Rating, ScopedCssBaseline, Select, Skeleton, Slide, Slider, Snackbar, SnackbarContent, SpeedDial, SpeedDialAction, SpeedDialIcon, Stack, Step, StepButton, StepConnector, StepContent, StepIcon, StepLabel, Stepper, SvgIcon, SwipeableDrawer, Switch, Tab, Table, TableBody, TableCell, TableContainer, TableFooter, TableHead, TablePagination, TableRow, TableSortLabel, Tabs, TabScrollButton, TextField, TextareaAutosize, ToggleButton, ToggleButtonGroup, Toolbar, Tooltip, Typography, useMediaQuery, useScrollTrigger, Zoom, useAutocomplete, GlobalStyles, emotionReact, emotionStyled, };

}
declare module '@hiiretail/react-foundation-ui' {
  import main = require('@hiiretail/react-foundation-ui/index');
  export = main;
}